/**
 * Close All Files on Project Switch.
 *
 * @category  WeBuilder Plugin
 * @package   Close All Files on Project Switch
 * @author    Peter Klein <pmk@io.dk>
 * @copyright 2017
 * @license   http://www.freebsd.org/copyright/license.html  BSD License
 * @version   0.10
 */

/**
 * [CLASS/FUNCTION INDEX of SCRIPT]
 *
 *     29   function CloseAllOpenDocuments()
 *     42   function OnLeavingProject(Sender)
 *     53   function OnInstalled()
 *
 * TOTAL FUNCTIONS: 3
 * (This index is automatically created/updated by the WeBuilder plugin "DocBlock Comments")
 *
 */

/**
 * Close all open documents
 *
 * @return void
 */
function CloseAllOpenDocuments() {
	for (var i=Documents.Count-1; i>=0; i--) {
	    Documents.Tab[i].Close(false);
	}
}

/**
 * Event triggered when leaving project
 *
 * @param  object   Sender
 *
 * @return void
 */
function OnLeavingProject(Sender) {
	if (Script.ReadSetting("Close All Files on Project Switch?", "0") == "1") {
		CloseAllOpenDocuments();
	}
}

/**
 * Show info when plugin is installed.
 *
 * @return void
 */
function OnInstalled() {
  Alert("Close All Files on Project Switch 0.10 by Peter Klein installed sucessfully!");
}

Script.ConnectSignal("installed", "OnInstalled");
Script.ConnectSignal("project_before_select", "OnLeavingProject");
